@@ -1,27 +1,28 @@
 package Editor;
 
-use Qt qw($app %Key);
+use Qt 2.0;
+use Qt::app;
 
-use slots 'load()', 'loadFile(cstring)', 'save()', 'create()', 'print()';
+use Qt::slots 'load()', 'loadFile(string)', 'save()', 'create()', 'print()';
 
-@ISA = qw(QWidget);
+@ISA = qw(Qt::Widget);
 
 sub new {
     my $self = shift->SUPER::new(@_);
 
-    my $m = QMenuBar->new($self, 'menu');
-    my $file = QPopupMenu->new;
+    my $m = Qt::MenuBar->new($self, 'menu');
+    my $file = Qt::PopupMenu->new;
     $m->insertItem('&File', $file);
 
-    $file->insertItem('New', $self, 'create()', $Key{Alt}+$Key{N});
-    $file->insertItem('Open', $self, 'load()', $Key{Alt}+$Key{O});
-    $file->insertItem('Save', $self, 'save()', $Key{Alt}+$Key{S});
+    $file->insertItem('New', $self, 'create()', Qt::ALT+Qt::Key_N);
+    $file->insertItem('Open', $self, 'load()', Qt::ALT+Qt::Key_O);
+    $file->insertItem('Save', $self, 'save()', Qt::ALT+Qt::Key_S);
     $file->insertSeparator();
-    $file->insertItem('Print', $self, 'print()', $Key{Alt}+$Key{P});
+    $file->insertItem('Print', $self, 'print()', Qt::ALT+Qt::Key_P);
     $file->insertSeparator();
-    $file->insertItem('Quit', $app, 'quit()', $Key{Alt}+$Key{Q});
+    $file->insertItem('Quit', $app, 'quit()', Qt::ALT+Qt::Key_Q);
 
-    my $e = QMultiLineEdit->new($self, 'editor');
+    my $e = Qt::MultiLineEdit->new($self, 'editor');
 
     @$self{'m', 'e'} = ($m, $e);
     return $self;
@@ -39,14 +40,14 @@ sub resizeEvent {
 
 sub load {
     my $self = shift;
-    my $fn = QFileDialog::getOpenFileName();
+    my $fn = Qt::FileDialog::getOpenFileName();
 
     $self->loadFile($fn) if $fn;
 }
 
 sub loadFile {
     my $self = shift;
-    my $e = $$self{'e'};
+    my $e = $self->{'e'};
     my $fileName = shift;
 
     open(FILE, $fileName) || return;
