@@ -28,6 +28,7 @@ PIG_DECLARE_TYPE(pig_type_qt_bitslen)
 PIG_DECLARE_TYPE(pig_type_qt_ubits)
 PIG_DECLARE_TYPE(pig_type_qt_ubitsarray)
 PIG_DECLARE_TYPE(pig_type_qt_uintarray)
+PIG_DECLARE_TYPE(pig_type_qt_pointarrayitems)
 
 PIG_DECLARE_TYPE(pig_type_qt_HVorientation)
 PIG_DECLARE_TYPE(pig_type_qt_VHorientation)
@@ -67,6 +68,7 @@ PIGTYPE_ARGUMENT(pig_type_qt_bits, char *)
 PIGTYPE_ARGUMENT2(pig_type_qt_bitslen, int, int)
 PIGTYPE_RETURN(pig_type_qt_ubits, unsigned char *)
 PIGTYPE_RETURN(pig_type_qt_uintarray, unsigned int *)
+PIGTYPE_ARGUMENT2(pig_type_qt_pointarrayitems, int, int)
 
 PIGTYPE_ALL(pig_type_qt_HVorientation, int)
 PIGTYPE_ALL(pig_type_qt_VHorientation, int)
@@ -114,6 +116,7 @@ PIG_IMPORT_TABLE(pigtype_qt)
     PIG_IMPORT_TYPE(pig_type_qt_ubits, "Qt ubits")
     PIG_IMPORT_TYPE(pig_type_qt_ubitsarray, "Qt ubits[]")
     PIG_IMPORT_TYPE(pig_type_qt_uintarray, "Qt uint[]")
+    PIG_IMPORT_TYPE(pig_type_qt_pointarrayitems, "Qt sizeof(point[])")
     PIG_IMPORT_TYPE(pig_type_qt_HVorientation, "Qt HVorientation")
     PIG_IMPORT_TYPE(pig_type_qt_VHorientation, "Qt VHorientation")
     PIG_IMPORT_TYPE(pig_type_qt_QString_ptr, "Qt QString*")
